/**
 * @file
 * Hides iframes when functional cookies are not accepted.
 */

(function ($, Drupal, once) {
  'use strict';

  Drupal.behaviors.cookie_information_iframes = {
    attach: function (context) {
      $(once('cookieinformation-iframe', 'iframe', context)).each(function () {
        // Cookie information also generates an iframe element to the <head> section which we
        // don't want to block.
        // We also ignore iframe blocking if data-ignore-cookie-blocking is set
        // to true.
        if (
          $(this).data('ignoreCookieBlocking') !== true &&
          $(this).attr('name') !== 'cookie-information-sharinglibrary-iframe'
        ) {
          $(this).attr('data-consent-src', $(this).attr('src'));
          $(this).attr('data-category-consent', 'cookie_cat_functional');
          $(this).removeAttr('src');
          var consent_given = CookieInformation.getConsentGivenFor(
            'cookie_cat_functional'
          );
          var display_style = consent_given ? 'none' : 'block';
          $(this).after(
            '<div class="consent-placeholder" data-category="cookie_cat_functional" style="display: ' +
              display_style +
              '">' +
              '<p class="consent-placeholder__text">' +
              Drupal.t(
                "Unfortunately you are not able to view this content since you haven't accepted functional cookies.",
                {},
                { context: 'Cookie information' }
              ) +
              '</p><button class="consent-placeholder__button" onClick="CookieConsent.renew()">' +
              Drupal.t(
                'Accept cookies',
                {},
                { context: 'Cookie information' }
              ) +
              '</button></div>'
          );
        }
      });
    },
  };
})(jQuery, Drupal, once);
